@@ -32,6 +32,16 @@
         <source>Window manager to use.</source>
         <translation>Gestore finestre da usare.</translation>
     </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <source>DBus Environment</source>
+        <translation type="unfinished">DBus Environment</translation>
+    </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
+        <translation>L&apos;ambiente di attivazione DBus non è stato aggiornato. Alcune app potrebbero non funzionare correttamente</translation>
+    </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
