@@ -32,6 +32,16 @@
         <source>Window manager to use.</source>
         <translation>De te gebruiken vensterbeheerder.</translation>
     </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <source>DBus Environment</source>
+        <translation>DBus-omgeving</translation>
+    </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
+        <translation>De DBus-activatie-omgeving is niet bijgewerkt. Sommige programma&apos;s werken mogelijk niet naar behoren.</translation>
+    </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
