@@ -32,6 +32,16 @@
         <source>Window manager to use.</source>
         <translation>Używany menedżer okien.</translation>
     </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <source>DBus Environment</source>
+        <translation>Środowisko DBus</translation>
+    </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
+        <translation>Środowisko aktywacji DBus nie zostało zaktualizowane. Niektóre aplikacje mogą nie działać poprawnie</translation>
+    </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
