@@ -32,6 +32,16 @@
         <source>Window manager to use.</source>
         <translation>Kullanılacak pencere yöneticisi.</translation>
     </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <source>DBus Environment</source>
+        <translation>DBus Ortamı</translation>
+    </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
+        <translation>DBus Etkinleştirme Ortamı güncellenmedi. Bazı uygulamalar düzgün çalışmayabilir</translation>
+    </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
